@@ -1101,6 +1101,7 @@ class SMTLinkTest extends SMTServiceHelper
         $testDetail->setPeakMonitoringOptionEnabled(SMTLicence::isPeakMonitoringOption($this->getContext()));
         $testDetail->setPeakToBtoDelta(SMTSmartOtuSettings::getPeakToBtoDeltaDbDefault());
         $testDetail->setMissingPeakThresholdPt($peakShift);
+        $testDetail->setMinAttenuationAlarmThreshold( $this->getMinAttenuationAlarmThreshold( $this->getModuleRunningNumber() ) );
         
 //         try
 //         {
@@ -1336,7 +1337,7 @@ class SMTLinkTest extends SMTServiceHelper
     	$testDetail->setPeakToBtoDelta(SMTSmartOtuSettings::getPeakToBtoDeltaDbDefault());
     	$testDetail->setMissingPeakThresholdPt(SMTSmartOtuSettings::getMissingPeakThresholdPtDefault());
     	$testDetail->setPeakShiftMode( SMTPeakShiftMode::getDefaultPeakShiftMode() );
-    	
+    	$testDetail->setMinAttenuationAlarmThreshold( $this->getMinAttenuationAlarmThreshold( $linkTestDto->getModuleRunningNumber() ) );
     	$linkTestDto->setTestDetail($testDetail);
     	    
     	return $linkTestDto;
@@ -1407,6 +1408,16 @@ class SMTLinkTest extends SMTServiceHelper
         return $portCount;
     }
 
+    /**
+     * Returns Minimum threshold for attenuation alarm or 0 if none is set
+     *
+     * @return float Minimum threshold for attenuation alarm or 0 if none is set
+     */
+    function getMinAttenuationAlarmThreshold( $moduleRunningNumber )
+    {
+    	return $this->sendReceive( SMTOtuApi::getMinAttenuationAlarmThreshold( SMTOtuApi::RES_MOD.$moduleRunningNumber) );
+    }
+    
     /**
      * Whether the OTU has a registered switch.
      *
@@ -1561,7 +1572,7 @@ class SMTLinkTest extends SMTServiceHelper
         catch(\Exception $e )
         {
         	throw new SMTLinkTestException( SMTLinkTestException::ERROR_TEST_NOT_FOUND, sprintf("Test not found %s!", $testId ) );
-        }        
+        }
         
     	if ( ( $linkDto = SMTMemoryManager::fetch( SMTLinkTestDto::getClass(), $linkId ) ) == NULL || $forceLinkTestRetrieval )
     	{
