@@ -1,4 +1,4 @@
-import subprocess
+import subprocess, os, time
 
 class Bootenv(object):
     def __init__(self):
@@ -26,5 +26,7 @@ class Bootenv(object):
         var = self.__dict__['__vars']
         var[k] = v
         subprocess.check_output(["fw_setenv", str(k), str(v)])
+        os.sync()
+        time.sleep(1)
 
 bootenv = Bootenv()
