@@ -21,12 +21,24 @@ REG_FORCE_COMB         = 0x54
 REG_FSM                = 0x58
 REG_COUNT_SYNC         = 0x5c
 REG_PRIME_RECUR        = 0x60
-REG_PRIME_CNT          = 0x64
+REG_DATA_LOG          = 0x64
 REG_DAC_VCC_APD        = 0x68
 REG_DAC_CONSIGNE_RAMAN = 0x6C
 REG_DAC_CONSIGNE_LASER = 0x70
 REG_DAC_CONSIGNE_TEC   = 0x74
 REG_DAC_CONSIGNE_TEC_AUTO = 0x78
+REG_DAC_CONSIGNE_LAS_DELTA = 0x7C
+REG_PID_Kp             = 0x80
+REG_PID_Ki             = 0x84
+REG_PID_Kd             = 0x88
+REG_PID_P_DEBUG        = 0x8C
+REG_PID_I_DEBUG        = 0x90
+REG_PID_D_DEBUG        = 0x94
+REG_PID_OUTPUT_DEBUG   = 0x98
+REG_PID_TEC_STATUS     = 0x9C
+REG_AVG_CURRENT        = 0xA0
+REG_DUTY_CYCLE         = 0xA4
+
 
 REG_MISC_LASER_IN_PROGRESS = 0x00200000
 REG_MISC_IRQ_BDT           = 0x00100000
